@@ -49,19 +49,29 @@
 
 package com.openexchange.file.storage.googledrive;
 
+import static com.openexchange.file.storage.googledrive.GoogleDriveConstants.ROOT_ID;
+import java.text.ParseException;
+import java.text.SimpleDateFormat;
 import java.util.Date;
 import java.util.EnumSet;
 import java.util.List;
 import java.util.Set;
+import java.util.TimeZone;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import com.google.api.client.util.DateTime;
 import com.google.api.services.drive.model.File;
+import com.google.api.services.drive.model.File.ImageMediaMetadata;
+import com.google.api.services.drive.model.File.ImageMediaMetadata.Location;
 import com.google.api.services.drive.model.Revision;
 import com.openexchange.exception.OXException;
 import com.openexchange.file.storage.DefaultFile;
 import com.openexchange.file.storage.FileStorageExceptionCodes;
 import com.openexchange.file.storage.FileStorageFileAccess;
 import com.openexchange.file.storage.FileStorageFolder;
+import com.openexchange.file.storage.MediaStatus;
 import com.openexchange.file.storage.googledrive.osgi.Services;
+import com.openexchange.java.GeoLocation;
 import com.openexchange.mime.MimeTypeMap;
 
 /**
@@ -71,6 +81,15 @@ import com.openexchange.mime.MimeTypeMap;
  */
 public final class GoogleDriveFile extends DefaultFile {
 
+    private final static Logger LOGGER = LoggerFactory.getLogger(GoogleDriveFile.class);
+
+    private final static SimpleDateFormat EXIF_FORMAT;
+
+    static {
+        EXIF_FORMAT = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
+        EXIF_FORMAT.setTimeZone(TimeZone.getTimeZone("UTC"));
+    }
+
     /**
      * Initializes a new {@link GoogleDriveFile}.
      *
@@ -91,7 +110,7 @@ public final class GoogleDriveFile extends DefaultFile {
     }
 
     private static boolean isRootFolder(String id, String rootFolderId) {
-        return "root".equals(id) || rootFolderId.equals(id);
+        return ROOT_ID.equals(id) || rootFolderId.equals(id);
     }
 
     @Override
@@ -122,19 +141,19 @@ public final class GoogleDriveFile extends DefaultFile {
     public GoogleDriveFile parseGoogleDriveFile(File file, List<Field> fields) throws OXException {
         if (null != file) {
             try {
-                final String name = file.getTitle();
+                final String name = file.getName();
                 setTitle(name);
                 setFileName(name);
 
                 final Set<Field> set = null == fields || fields.isEmpty() ? EnumSet.allOf(Field.class) : EnumSet.copyOf(fields);
                 if (set.contains(Field.CREATED)) {
-                    DateTime createdDate = file.getCreatedDate();
+                    DateTime createdDate = file.getCreatedTime();
                     if (null != createdDate) {
                         setCreated(new Date(createdDate.getValue()));
                     }
                 }
                 if (set.contains(Field.LAST_MODIFIED) || set.contains(Field.LAST_MODIFIED_UTC)) {
-                    DateTime modifiedDate = file.getModifiedDate();
+                    DateTime modifiedDate = file.getModifiedTime();
                     if (null != modifiedDate) {
                         setLastModified(new Date(modifiedDate.getValue()));
                     }
@@ -148,7 +167,7 @@ public final class GoogleDriveFile extends DefaultFile {
                     setFileMIMEType(contentType);
                 }
                 if (set.contains(Field.FILE_SIZE)) {
-                    Long fileSize = file.getFileSize();
+                    Long fileSize = file.getSize();
                     if (null != fileSize) {
                         setFileSize(fileSize.longValue());
                     }
@@ -171,6 +190,78 @@ public final class GoogleDriveFile extends DefaultFile {
                 if (set.contains(Field.FILE_MD5SUM)) {
                     setFileMD5Sum(file.getMd5Checksum());
                 }
+                // ---------- MEDIA STUFF ----------
+                ImageMediaMetadata imageMediaMetadata = file.getImageMediaMetadata();
+                if (null != imageMediaMetadata) {
+                    setMediaStatus(MediaStatus.valueFor(MediaStatus.Status.DONE_SUCCESS));
+                    if (set.contains(Field.CAPTURE_DATE)) {
+                        if (null != imageMediaMetadata.getTime()) {
+                            try {
+                                Date date;
+                                synchronized (EXIF_FORMAT) {
+                                    /*
+                                     * EXIF doesn't standardize time zones, therefore the actual time is best guess. Using UTC for the moment
+                                     */
+                                    date = EXIF_FORMAT.parse(imageMediaMetadata.getTime());
+                                }
+                                setCaptureDate(date);
+                            } catch (ParseException e) {
+                                LOGGER.debug("Unable to set capture date.", e);
+                            }
+                        }
+                    }
+                    if (set.contains(Field.GEOLOCATION)) {
+                        if (null != imageMediaMetadata.getLocation()) {
+                            Location location = imageMediaMetadata.getLocation();
+                            if (null != location.getLatitude() && null != location.getLongitude()) {
+                                setGeoLocation(new GeoLocation(location.getLatitude().doubleValue(), location.getLongitude().doubleValue()));
+                            }
+                        }
+                    }
+                    if (set.contains(Field.WIDTH)) {
+                        if (null != imageMediaMetadata.getWidth()) {
+                            setWidth(imageMediaMetadata.getWidth().longValue());
+                        }
+                    }
+                    if (set.contains(Field.HEIGHT)) {
+                        if (null != imageMediaMetadata.getHeight()) {
+                            setHeight(imageMediaMetadata.getHeight().longValue());
+                        }
+                    }
+                    if (set.contains(Field.CAMERA_MAKE)) {
+                        if (null != imageMediaMetadata.getCameraMake()) {
+                            setCameraMake(imageMediaMetadata.getCameraMake());
+                        }
+                    }
+                    if (set.contains(Field.CAMERA_MODEL)) {
+                        if (null != imageMediaMetadata.getCameraModel()) {
+                            setCameraModel(imageMediaMetadata.getCameraModel());
+                        }
+                    }
+                    if (set.contains(Field.CAMERA_ISO_SPEED)) {
+                        if (null != imageMediaMetadata.getIsoSpeed()) {
+                            setCameraIsoSpeed(imageMediaMetadata.getIsoSpeed().longValue());
+                        }
+                    }
+                    if (set.contains(Field.CAMERA_APERTURE)) {
+                        if (null != imageMediaMetadata.getAperture()) {
+                            setCameraAperture(imageMediaMetadata.getAperture().doubleValue());
+                        }
+                    }
+                    if (set.contains(Field.CAMERA_EXPOSURE_TIME)) {
+                        if (null != imageMediaMetadata.getExposureTime()) {
+                            setCameraExposureTime(imageMediaMetadata.getExposureTime().doubleValue());
+                        }
+                    }
+                    if (set.contains(Field.CAMERA_FOCAL_LENGTH)) {
+                        if (null != imageMediaMetadata.getFocalLength()) {
+                            setCameraFocalLength(imageMediaMetadata.getFocalLength().doubleValue());
+                        }
+                    }
+                } else {
+                    setMediaStatus(MediaStatus.valueFor(MediaStatus.Status.NONE));
+                }
+
             } catch (final RuntimeException e) {
                 throw FileStorageExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
             }
@@ -197,7 +288,7 @@ public final class GoogleDriveFile extends DefaultFile {
 
                 Set<Field> set = null == fields || fields.isEmpty() ? EnumSet.allOf(Field.class) : EnumSet.copyOf(fields);
                 if (set.contains(Field.LAST_MODIFIED) || set.contains(Field.LAST_MODIFIED_UTC)) {
-                    DateTime modifiedDate = revision.getModifiedDate();
+                    DateTime modifiedDate = revision.getModifiedTime();
                     if (null != modifiedDate) {
                         setLastModified(new Date(modifiedDate.getValue()));
                     }
@@ -211,13 +302,16 @@ public final class GoogleDriveFile extends DefaultFile {
                     setFileMIMEType(contentType);
                 }
                 if (set.contains(Field.FILE_SIZE)) {
-                    Long fileSize = revision.getFileSize();
+                    Long fileSize = revision.getSize();
                     if (null != fileSize) {
                         setFileSize(fileSize.longValue());
                     }
                 }
                 if (set.contains(Field.URL)) {
-                    setURL(revision.getDownloadUrl());
+                    Object webContentLink = revision.get("webContentLink");
+                    if (null != webContentLink && String.class.isAssignableFrom(webContentLink.getClass())) {
+                        setURL((String) webContentLink);
+                    }
                 }
                 if (set.contains(Field.FILE_MD5SUM)) {
                     setFileMD5Sum(revision.getMd5Checksum());
